package com.ynet.life.base.session;

import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.session.GENESession;
import com.ynet.gene.session.GENESessionManager;
import com.ynet.gene.session.Session;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.MVCEntity;
import com.ynet.life.base.TEntity;
import com.ynet.life.cache.Cache;
import com.ynet.life.exception.TranFailException;
import java.util.HashMap;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/* loaded from: com_ynet_life_base_session.jar:com/ynet/life/base/session/LifeSessionAndCacheManager.class */
public class LifeSessionAndCacheManager extends GENESessionManager {
    HttpServletRequest resquest;
    HttpServletResponse response;
    public static final String SESSION_TIMEOUT = "sessionTimeout";

    public Session getSession(Object requestObj, Object responseObj, boolean createWhenNotCreate) {
        String sessionId = null;
        HttpServletRequest request = null;
        if (requestObj instanceof String) {
            sessionId = (String) requestObj;
        } else if (requestObj instanceof HttpServletRequest) {
            HttpServletRequest httpServletRequest = (HttpServletRequest) requestObj;
            request = httpServletRequest;
            sessionId = httpServletRequest.getParameter(TEntity.appKeyFieldname);
        }
        Session session = (Session) getSessions().get(sessionId);
        if (session == null) {
            request.setAttribute(GENEConstance.GENE_SESSION_ID_LABEL, sessionId);
            return super.getSession(requestObj, responseObj, createWhenNotCreate);
        }
        return session;
    }

    protected boolean checkTimeout(GENESession session) {
        Long userSetTimeout = (Long) session.getAttribute("sessionTimeout");
        long timeout = userSetTimeout == null ? getSessionTimeOut() : userSetTimeout.longValue();
        return System.currentTimeMillis() - session.getLastAccessTime() > timeout;
    }

    public HashMap getAppendPostFieldMap(HttpServletRequest request) {
        HashMap resultMap = new HashMap();
        if (getSessionTraceType() != 0) {
            Session session = (Session) request.getAttribute(GENEConstance.ATTR_SESSION);
            resultMap.put(getSessionIdLabel(), session.getId());
        }
        return resultMap;
    }

    public void removeSession(Session session) {
        if (session == null) {
            return;
        }
        String sessionId = session.getId();
        String cacheServiceFlag = LifeStandard.getSelfDefineSettingsValue("cacheServiceFlag");
        if ("true".equals(cacheServiceFlag)) {
            Cache sessionDatacache = null;
            Cache cache = null;
            Cache bsnDataCache = null;
            try {
                sessionDatacache = LifeStandard.getCache("sessionData_cache");
                cache = LifeStandard.getCache("bsnData_cache");
                bsnDataCache = cache;
            } catch (TranFailException e) {
                cache.printStackTrace();
            }
            Object mvcEntity = sessionDatacache.get(sessionId);
            if (mvcEntity != null) {
                String singleKey = (String) getSingleDataKey(mvcEntity);
                sessionDatacache.remove(singleKey);
                String cusInfoKey = (String) getCacheCustomerInfoKey(mvcEntity);
                bsnDataCache.remove(cusInfoKey);
                sessionDatacache.remove(sessionId);
            }
        }
        super.removeSession(session);
    }

    public Object getSingleDataKey(Object obj) {
        String key = null;
        if (obj != null) {
            MVCEntity mvcEntity = (MVCEntity) obj;
            String bankId = mvcEntity.getBankId();
            String logonId = mvcEntity.getLogonId();
            String reqAppFlag = mvcEntity.getReqAppFlag();
            if (TEntity.REQ_APP_JRB.equals(reqAppFlag)) {
                key = String.valueOf(bankId) + "_" + logonId;
            }
        }
        return key;
    }

    public Object getCacheCustomerInfoKey(Object obj) {
        String key = null;
        if (obj != null) {
            MVCEntity mvcEntity = (MVCEntity) obj;
            String bankId = mvcEntity.getBankId();
            String logonId = mvcEntity.getLogonId();
            mvcEntity.getChannel();
            String reqAppFlag = mvcEntity.getReqAppFlag();
            if (TEntity.REQ_APP_JRB.equals(reqAppFlag)) {
                key = String.valueOf(bankId) + "_" + logonId;
            }
        }
        return key;
    }
}
